@@ -4,9 +4,9 @@ use strict;
 use HTML::SuperForm::Field;
 use Carp;
 
-our $VERSION = 1.08;
+our $VERSION = 1.09;
 
-my %fields = map { $_ => 1 } qw(textarea text checkbox select radio checkbox_group radio_group password hidden submit);
+my %fields = map { $_ => 1 } qw(textarea text checkbox select radio checkbox_group radio_group password hidden submit reset);
 my %mutators    = map { $_ => 1 } qw(well_formed sticky fallback values_as_labels);
 my %accessors    = map { $_ => 1 } qw(field_object params);
 
